<?php

declare(strict_types=1);

namespace Drupal\pie_chart\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\node\Entity\NodeType;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\user\Entity\User;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\EntityFieldManagerInterface;
/**
 * Returns responses for Node Pie Chart routes.
 */
final class NodePieChartController extends ControllerBase
{
    /**
     * Builds the response.
     */
    public function getNodeData()
    {
        $node_types = NodeType::loadMultiple();
        $content_types = [];
        $node_counts = [];
        foreach ($node_types as $type) {
            $type_id = $type->id();
            $type_label = $type->label();
            $content_types[] = $type_label;
            // Query to get the node count for the current content type.
            $query = \Drupal::database()
                ->select("node_field_data", "nfd")
                ->condition("nfd.type", $type_id)
                ->condition("nfd.status", 1)
                ->countQuery();
            $count = $query->execute()->fetchField();
            // Store the node count in the array.
            $node_counts[$type_label] = $count;
        }
        $build = [
            "#theme" => "node-data",
            "#content_types" => $content_types,
            "#node_counts" => $node_counts,
        ];
        // Attach JavaScript settings
        $build["#attached"]["drupalSettings"]["pie_chart"][
            "node_counts"
        ] = $node_counts;
        return $build;
    }

    /**
     * Send the response in the block.
     */
    public function sendNodedataBlock()
    {   
        $node_types = NodeType::loadMultiple();
        // Initialize arrays to store the content types and node counts.
        $content_types = [];
        $node_counts = [];
        foreach ($node_types as $type) {
            $type_id = $type->id();
            $type_label = $type->label();
            $content_types[] = $type_label;
            // Query to get the node count for the current content type.
            $query = \Drupal::database()
                ->select("node_field_data", "nfd")
                ->condition("nfd.type", $type_id)
                ->condition("nfd.status", 1)
                ->countQuery();
            $count = $query->execute()->fetchField();
            $node_counts[$type_label] = $count;
        }
        return $node_counts;
    }

    /**
     * Count users by role.
     */
    public function getUserData()
    {
        $user_field_definitions = \Drupal::service(
            "entity_field.manager"
        )->getFieldDefinitions("user", "fields");
        $roles = user_roles(true);
        $counts = [];
        foreach ($roles as $role_id => $role) {
            $query = \Drupal::entityTypeManager()
                ->getStorage("user")
                ->getQuery();
            $query
                ->accessCheck(false)
                ->condition("status", 1)
                ->condition("roles", $role_id);
            $count = $query->count()->execute();
            $user_role = $roles[$role_id]->label();
            $counts[$user_role] = $count;
        }
        $build = [
            "#theme" => "user-data",
            "#counts" => $counts,
            "#attached" => [
                "library" => ["pie_chart/drupal.pie_chart"],
                "drupalSettings" => [
                    "userCounts" => $counts,
                ],
            ],
        ];
        return $build;
    }
}
